INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('AB', 'Alberta', 1);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('BC', 'British Columbia', 1);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('MB', 'Manitoba', 1);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('NB', 'New Brunswick', 1);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('NL', 'Newfoundland and Labrador', 1);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('NS', 'Nova Scotia', 1);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('NT', 'Northwest Territories', 1);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('NU', 'Nunavut', 1);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('ON', 'Ontario', 1);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('PE', 'Prince Edward Island', 1);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('QC', 'Québec', 1);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('SK', 'Saskatchewan', 1);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('YT', 'Yukon', 1);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('001', 'Brändö', 5);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('002', 'Eckerö', 5);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('003', 'Finström', 5);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('004', 'Föglö', 5);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('005', 'Geta', 5);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('006', 'Hammarland', 5);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('007', 'Jomala', 5);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('008', 'Kumlinge', 5);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('009', 'Kökar', 5);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('010', 'Lemland', 5);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('011', 'Lumparland', 5);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('012', 'Maarianhamina', 5);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('013', 'Saltvik', 5);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('014', 'Sottunga', 5);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('015', 'Sund', 5);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('016', 'Vårdö', 5);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('AK', 'Alaska', 6);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('AN', 'Andaman and Nicobar Islands', 11);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('AL', 'Altaysky Kraj', 15);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('AM', 'Amurskaya oblast', 15);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('BA', 'Republic of Bashkortostan', 15);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('BU', 'Republic of Buryatia', 15);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('CB', 'Chelyabinsk', 15);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('CK', 'Chukotka Autonomous Okrug', 15);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('CT', 'Zabaykalsky Kraj', 15);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('EA', 'Yevreyskaya Autonomous Oblast', 15);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('GA', 'Republic Gorny Altay', 15);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('HA', 'Republic of Khakassia', 15);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('HK', 'Khabarovsk', 15);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('HM', 'Khanty-Mansyisky Autonomous Okrug', 15);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('IR', 'Irkutsk', 15);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('KE', 'Kemerovo', 15);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('KK', 'Krasnoyarsk', 15);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('KN', 'Kurgan', 15);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('KO', 'Republic of Komi', 15);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('KT', 'Kamchatka', 15);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('MG', 'Magadan', 15);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('NS', 'Novosibirsk', 15);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('OB', 'Orenburg', 15);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('OM', 'Omsk', 15);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('PK', 'Primorsky Kraj', 15);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('PM', 'Perm`', 15);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('SL', 'Sakhalin', 15);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('SV', 'Sverdlovskaya oblast', 15);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('TN', 'Tyumen''', 15);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('TO', 'Tomsk', 15);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('TU', 'Republic of Tuva', 15);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('YA', 'Republic of Sakha', 15);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('YN', 'Yamalo-Nenetsky Autonomous Okrug', 15);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('IB', 'Balears', 21);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('BR', 'Brest', 27);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('HM', 'Horad Minsk', 27);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('HO', 'Gomel', 27);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('HR', 'Grodno', 27);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('MA', 'Mogilev', 27);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('MI', 'Minsk', 27);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('VI', 'Vitebsk', 27);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('GC', 'Las Palmas', 29);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('TF', 'Santa Cruz de Tenerife', 29);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('CE', 'Ceuta', 32);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('ML', 'Melilla', 32);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('AGS', 'Aguascalientes', 50);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('AGU', 'Aguascalientes', 50);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('BC', 'Baja California', 50);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('BCN', 'Baja California', 50);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('BCS', 'Baja California Sur', 50);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('CAM', 'Campeche', 50);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('CHH', 'Chihuahua', 50);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('CHP', 'Chiapas', 50);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('CHS', 'Chiapas', 50);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('CMX', 'Ciudad de México', 50);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('COA', 'Coahuila de Zaragoza', 50);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('COL', 'Colima', 50);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('DF', 'Distrito Federal', 50);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('DGO', 'Durango', 50);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('DUR', 'Durango', 50);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('EMX', 'Estado de México', 50);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('GRO', 'Guerrero', 50);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('GTO', 'Guanajuato', 50);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('GUA', 'Guanajuato', 50);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('HGO', 'Hidalgo', 50);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('HID', 'Hidalgo', 50);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('JAL', 'Jalisco', 50);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('MEX', 'México', 50);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('MIC', 'Michoacán de Ocampo', 50);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('MOR', 'Morelos', 50);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('NAY', 'Nayarit', 50);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('NL', 'Nuevo Leon', 50);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('NLE', 'Nuevo León', 50);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('OAX', 'Oaxaca', 50);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('PUE', 'Puebla', 50);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('QRO', 'Querétaro de Arteaga', 50);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('QTR', 'Quintana Roo', 50);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('QUE', 'Querétaro', 50);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('ROO', 'Quintana Roo', 50);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('SIN', 'Sinaloa', 50);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('SLP', 'San Luis Potosí', 50);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('SON', 'Sonora', 50);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('TAB', 'Tabasco', 50);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('TAM', 'Tamaulipas', 50);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('TLA', 'Tlaxcala', 50);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('TLX', 'Tlaxcala', 50);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('TMS', 'Tamaulipas', 50);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('VER', 'Veracruz de Ignacio de la Llave', 50);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('YUC', 'Yucatán', 50);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('ZAC', 'Zacatecas', 50);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('AD', 'Republic of Adygeya', 54);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('AO', 'Astrakhan''', 54);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('AR', 'Arkhangelsk', 54);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('BO', 'Belgorod', 54);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('BR', 'Bryansk', 54);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('CN', 'Republic Chechnya', 54);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('CU', 'Republic of Chuvashia', 54);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('DA', 'Republic of Daghestan', 54);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('IN', 'Republic of Ingushetia', 54);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('IV', 'Ivanovo', 54);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('KB', 'Republic of Kabardino-Balkaria', 54);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('KC', 'Republic of Karachaevo-Cherkessia', 54);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('KG', 'Kaluga', 54);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('KI', 'Kirov', 54);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('KL', 'Republic of Karelia', 54);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('KM', 'Republic of Kalmykia', 54);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('KR', 'Krasnodar', 54);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('KS', 'Kostroma', 54);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('KU', 'Kursk', 54);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('LO', 'Leningradskaya oblast', 54);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('LP', 'Lipetsk', 54);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('MA', 'City of Moscow', 54);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('MD', 'Republic of Mordovia', 54);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('MO', 'Moscowskaya oblast', 54);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('MR', 'Republic of Marij-El', 54);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('MU', 'Murmansk', 54);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('NN', 'Nizhni Novgorod', 54);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('NO', 'Nenetsky Autonomous Okrug', 54);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('NV', 'Novgorodskaya oblast', 54);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('OR', 'Oryel', 54);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('PE', 'Penza', 54);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('PS', 'Pskov', 54);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('RA', 'Ryazan''', 54);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('RO', 'Rostov-on-Don', 54);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('SA', 'Saratov', 54);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('SM', 'Smolensk', 54);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('SO', 'Republic of Northern Ossetia', 54);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('SP', 'City of St. Petersburg', 54);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('SR', 'Samara', 54);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('ST', 'Stavropol''', 54);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('TA', 'Republic of Tataria', 54);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('TB', 'Tambov', 54);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('TL', 'Tula', 54);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('TV', 'Tver''', 54);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('UD', 'Republic of Udmurtia', 54);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('UL', 'Ulyanovsk', 54);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('VG', 'Volgograd', 54);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('VL', 'Vladimir', 54);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('VO', 'Vologda', 54);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('VR', 'Voronezh', 54);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('YR', 'Yaroslavl', 54);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('AR', 'Arkhangelsk', 61);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('FJL', 'Franz Josef Land', 61);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('01', 'Pinar del Río', 70);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('03', 'La Habana', 70);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('04', 'Matanzas', 70);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('05', 'Villa Clara', 70);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('06', 'Cienfuegos', 70);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('07', 'Sancti Spíritus', 70);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('08', 'Ciego de Ávila', 70);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('09', 'Camagüey', 70);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('10', 'Las Tunas', 70);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('11', 'Holguín', 70);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('12', 'Granma', 70);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('13', 'Santiago de Cuba', 70);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('14', 'Guantánamo', 70);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('15', 'Artemisa', 70);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('16', 'Mayabeque', 70);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('99', 'Isla de la Juventud', 70);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('A', 'Salta', 100);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('B', 'Buenos Aires Province', 100);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('C', 'Capital federal', 100);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('D', 'San Luis', 100);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('E', 'Entre Ríos', 100);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('F', 'La Rioja', 100);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('G', 'Santiago del Estero', 100);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('H', 'Chaco', 100);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('J', 'San Juan', 100);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('K', 'Catamarca', 100);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('L', 'La Pampa', 100);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('M', 'Mendoza', 100);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('N', 'Misiones', 100);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('P', 'Formosa', 100);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('Q', 'Neuquén', 100);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('R', 'Río Negro', 100);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('S', 'Santa Fe', 100);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('T', 'Tucumán', 100);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('U', 'Chubut', 100);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('V', 'Tierra del Fuego', 100);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('W', 'Corrientes', 100);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('X', 'Córdoba', 100);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('Y', 'Jujuy', 100);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('Z', 'Santa Cruz', 100);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('AC', 'Acre', 108);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('AL', 'Alagoas', 108);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('AM', 'Amazonas', 108);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('AP', 'Amapá', 108);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('BA', 'Bahia', 108);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('CE', 'Ceará', 108);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('DF', 'Distrito Federal', 108);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('ES', 'Espírito Santo', 108);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('GO', 'Goiás', 108);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('MA', 'Maranhão', 108);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('MG', 'Minas Gerais', 108);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('MS', 'Mato Grosso do Sul', 108);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('MT', 'Mato Grosso', 108);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('PA', 'Pará', 108);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('PB', 'Paraíba', 108);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('PE', 'Pernambuco', 108);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('PI', 'Piauí', 108);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('PR', 'Paraná', 108);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('RJ', 'Rio de Janeiro', 108);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('RN', 'Rio Grande do Norte', 108);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('RO', 'Rondônia', 108);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('RR', 'Roraima', 108);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('RS', 'Rio Grande do Sul', 108);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('SC', 'Santa Catarina', 108);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('SE', 'Sergipe', 108);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('SP', 'São Paulo', 108);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('TO', 'Tocantins', 108);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('HI', 'Hawaii', 110);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('AI', 'Aisén del General Carlos Ibañez del Campo', 112);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('AN', 'Antofagasta', 112);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('AP', 'Arica y Parinacota', 112);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('AR', 'La Araucanía', 112);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('AT', 'Atacama', 112);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('BI', 'Biobío', 112);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('CO', 'Coquimbo', 112);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('I', 'Tarapacá', 112);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('II', 'Antofagasta', 112);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('III', 'Atacama', 112);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('IV', 'Coquimbo', 112);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('IX', 'La Araucanía', 112);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('LI', 'Libertador General Bernardo O''Higgins', 112);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('LL', 'Los Lagos', 112);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('LR', 'Los Ríos', 112);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('MA', 'Magallanes', 112);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('ML', 'Maule', 112);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('NB', 'Ñuble', 112);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('RM', 'Region Metropolitana de Santiago', 112);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('TA', 'Tarapacá', 112);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('V', 'Valparaíso', 112);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('VI', 'Libertador General Bernardo O''Higgins', 112);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('VII', 'Maule', 112);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('VIII', 'Bío-Bío', 112);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('VS', 'Valparaíso', 112);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('X', 'Los Lagos', 112);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('XI', 'Aisén del General Carlos Ibáñez del Campo', 112);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('XII', 'Magallanes', 112);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('XIV', 'Los Ríos', 112);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('XV', 'Arica y Parinacota', 112);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('22', 'Jan Mayen', 118);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('KA', 'Kalingrad', 126);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('01', 'Concepción', 132);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('02', 'San Pedro', 132);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('03', 'Cordillera', 132);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('04', 'Guairá', 132);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('05', 'Caeguazú', 132);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('06', 'Caazapl', 132);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('07', 'Itapua', 132);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('08', 'Miaiones', 132);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('09', 'Paraguarí', 132);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('1', 'Concepción', 132);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('10', 'Alto Paraná', 132);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('11', 'Central', 132);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('12', 'Ñeembucú', 132);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('13', 'Amambay', 132);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('14', 'Canindeyú', 132);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('15', 'Presidente Hayes', 132);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('16', 'Alto Paraguay', 132);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('19', 'Boquerón', 132);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('2', 'San Pedro', 132);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('3', 'Cordillera', 132);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('4', 'Guairá', 132);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('5', 'Caeguazú', 132);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('6', 'Caazapá', 132);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('7', 'Itapúa', 132);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('8', 'Misiones', 132);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('9', 'Paraguarí', 132);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('ASU', 'Asunción', 132);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('A', 'Seoul', 137);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('B', 'Pusan', 137);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('C', 'Kyunggi-do', 137);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('D', 'Kangwon-do', 137);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('E', 'Choongchungbuk-do', 137);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('F', 'Choongchungnam-do', 137);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('G', 'Chollabuk-do', 137);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('H', 'Chollanam-do', 137);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('IS', 'Special Island', 137);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('K', 'Kyungsangbuk-do', 137);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('L', 'Kyungsangnam-do', 137);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('M', 'Cheju-do', 137);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('N', 'Inchon', 137);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('P', 'Taegu', 137);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('Q', 'Kwangju', 137);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('R', 'Taejon', 137);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('S', 'Ulsan', 137);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('T', 'Sejong', 137);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('KI', 'Kure Island', 138);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('LD', 'Lakshadweep', 142);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('AR', 'Artigas', 144);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('CA', 'Canelones', 144);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('CL', 'Cerro Largo', 144);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('CO', 'Colonia', 144);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('DU', 'Durazno', 144);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('FD', 'Florida', 144);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('FS', 'Flores', 144);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('LA', 'Lavalleja', 144);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('MA', 'Maldonado', 144);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('MO', 'Montevideo', 144);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('PA', 'Paysandú', 144);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('RN', 'Río Negro', 144);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('RO', 'Rocha', 144);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('RV', 'Rivera', 144);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('SA', 'Salto', 144);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('SJ', 'San José', 144);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('SO', 'Soriano', 144);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('TA', 'Tacuarembó', 144);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('TT', 'Treinta y Tres', 144);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('LH', 'Lord Howe Is', 147);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('AM', 'Amazonas', 148);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('AN', 'Anzoátegui', 148);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('AP', 'Apure', 148);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('AR', 'Aragua', 148);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('BA', 'Barinas', 148);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('BO', 'Bolívar', 148);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('CA', 'Carabobo', 148);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('CO', 'Cojedes', 148);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('DA', 'Delta Amacuro', 148);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('DC', 'Distrito Capital', 148);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('FA', 'Falcón', 148);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('GU', 'Guárico', 148);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('LA', 'Lara', 148);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('ME', 'Mérida', 148);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('MI', 'Miranda', 148);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('MO', 'Monagas', 148);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('NE', 'Nueva Esparta', 148);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('PO', 'Portuguesa', 148);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('SU', 'Sucre', 148);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('TA', 'Táchira', 148);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('TR', 'Trujillo', 148);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('VA', 'Vargas', 148);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('YA', 'Yaracuy', 148);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('ZU', 'Zulia', 148);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('AC', 'Açores', 149);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('ACT', 'Australian Capital Territory', 150);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('NSW', 'New South Wales', 150);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('NT', 'Northern Territory', 150);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('QLD', 'Queensland', 150);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('SA', 'South Australia', 150);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('TAS', 'Tasmania', 150);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('VIC', 'Victoria', 150);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('WA', 'Western Australia', 150);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('LO', 'Leningradskaya Oblast', 151);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('MV', 'Malyj Vysotskij', 151);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('MA', 'Macquarie Is', 153);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('CPK', 'Chimbu', 163);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('CPM', 'Central', 163);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('EBR', 'East New Britain', 163);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('EHG', 'Eastern Highlands', 163);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('EPW', 'Enga', 163);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('ESW', 'East Sepik', 163);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('GPK', 'Gulf', 163);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('HLA', 'Hela', 163);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('JWK', 'Jiwaka', 163);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('MBA', 'Milne Bay', 163);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('MPL', 'Morobe', 163);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('MPM', 'Madang', 163);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('MRL', 'Manus', 163);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('NCD', 'National Capital District', 163);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('NIK', 'New Ireland', 163);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('NPP', 'Northern', 163);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('NSA', 'North Solomons', 163);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('NSB', 'Bougainville', 163);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('SAN', 'West Sepik', 163);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('SHM', 'Southern Highlands', 163);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('WBK', 'West New Britain', 163);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('WBR', 'West New Britain', 163);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('WHM', 'Western Highlands', 163);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('WPD', 'Western', 163);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('AUK', 'Auckland', 170);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('BOP', 'Bay of Plenty', 170);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('CAN', 'Canterbury', 170);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('GIS', 'Gisborne', 170);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('HKB', 'Hawke''s Bay', 170);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('MBH', 'Marlborough', 170);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('MWT', 'Manawatū-Whanganui', 170);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('NSN', 'Nelson', 170);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('NTL', 'Northland', 170);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('OTA', 'Otago', 170);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('STL', 'Southland', 170);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('TAS', 'Tasman', 170);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('TKI', 'Taranaki', 170);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('WGN', 'Greater Wellington', 170);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('WKO', 'Waikato', 170);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('WTC', 'West Coast', 170);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('MT', 'Minami Torishima', 177);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('O', 'Ogasawara', 192);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('AM', 'Amstetten', 206);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('BC', 'Bregenz', 206);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('BL', 'Bruck/Leitha', 206);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('BM', 'Bruck-Mürzzuschlag', 206);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('BN', 'Baden', 206);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('BR', 'Braunau/Inn', 206);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('BZ', 'Bludenz', 206);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('DL', 'Deutschlandsberg', 206);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('DO', 'Dornbirn', 206);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('EC', 'Eisenstadt', 206);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('EF', 'Eferding', 206);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('EU', 'Eisenstadt-Umgebung', 206);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('FE', 'Feldkirchen', 206);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('FK', 'Feldkirch', 206);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('FR', 'Freistadt', 206);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('GB', 'Gröbming', 206);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('GC', 'Graz', 206);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('GD', 'Gmünd', 206);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('GF', 'Gänserndorf', 206);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('GM', 'Gmunden', 206);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('GR', 'Grieskirchen', 206);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('GS', 'Güssing', 206);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('GU', 'Graz-Umgebung', 206);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('HA', 'Hallein', 206);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('HE', 'Hermagor', 206);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('HF', 'Hartberg-Fürstenfeld', 206);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('HL', 'Hollabrunn', 206);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('HO', 'Horn', 206);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('IC', 'Innsbruck', 206);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('IL', 'Innsbruck-Land', 206);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('IM', 'Imst', 206);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('JE', 'Jennersdorf', 206);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('JO', 'St. Johann', 206);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('KB', 'Kitzbühel', 206);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('KC', 'Klagenfurt', 206);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('KI', 'Kirchdorf', 206);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('KL', 'Klagenfurt-Land', 206);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('KO', 'Korneuburg', 206);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('KR', 'Krems-Region', 206);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('KS', 'Krems', 206);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('KU', 'Kufstein', 206);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('LA', 'Landeck', 206);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('LB', 'Leibnitz', 206);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('LC', 'Linz', 206);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('LE', 'Leoben', 206);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('LF', 'Lilienfeld', 206);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('LI', 'Liezen', 206);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('LL', 'Linz-Land', 206);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('LN', 'Leoben-Land', 206);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('LZ', 'Lienz', 206);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('MA', 'Mattersburg', 206);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('MD', 'Mödling', 206);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('ME', 'Melk', 206);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('MI', 'Mistelbach', 206);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('MT', 'Murtal', 206);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('MU', 'Murau', 206);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('ND', 'Neusiedl/See', 206);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('NK', 'Neunkirchen', 206);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('OP', 'Oberpullendorf', 206);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('OW', 'Oberwart', 206);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('PC', 'St. Pölten', 206);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('PE', 'Perg', 206);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('PL', 'St. Pölten-Land', 206);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('RE', 'Reutte', 206);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('RI', 'Ried/Innkreis', 206);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('RO', 'Rohrbach', 206);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('SB', 'Scheibbs', 206);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('SC', 'Salzburg', 206);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('SD', 'Schärding', 206);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('SE', 'Steyr-Land', 206);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('SL', 'Salzburg-Land', 206);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('SO', 'Südoststeiermark', 206);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('SP', 'Spittal/Drau', 206);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('SR', 'Steyr', 206);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('SV', 'St.Veit/Glan', 206);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('SW', 'Schwechat', 206);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('SZ', 'Schwaz', 206);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('TA', 'Tamsweg', 206);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('TU', 'Tulln', 206);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('UU', 'Urfahr', 206);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('VB', 'Vöcklabruck', 206);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('VI', 'Villach', 206);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('VK', 'Völkermarkt', 206);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('VL', 'Villach-Land', 206);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('VO', 'Voitsberg', 206);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('WB', 'Wr.Neustadt-Bezirk', 206);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('WC', 'Wien', 206);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('WE', 'Wels', 206);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('WL', 'Wels-Land', 206);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('WN', 'Wr.Neustadt', 206);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('WO', 'Wolfsberg', 206);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('WT', 'Waidhofen/Thaya', 206);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('WU', 'Wien-Umgebung', 206);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('WY', 'Waidhofen/Ybbs', 206);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('WZ', 'Weiz', 206);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('ZE', 'Zell Am See', 206);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('ZT', 'Zwettl', 206);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('AN', 'Antwerpen', 209);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('BR', 'Brussels', 209);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('BW', 'Brabant Wallon', 209);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('HT', 'Hainaut', 209);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('LB', 'Limburg', 209);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('LG', 'Liêge', 209);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('LU', 'Luxembourg', 209);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('NM', 'Namur', 209);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('OV', 'Oost-Vlaanderen', 209);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('VB', 'Vlaams Brabant', 209);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('WV', 'West-Vlaanderen', 209);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('BL', 'Blagoevgrad', 212);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('BU', 'Burgas', 212);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('DO', 'Dobrič', 212);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('GA', 'Gabrovo', 212);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('HA', 'Haskovo', 212);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('KA', 'Kărdžali', 212);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('KD', 'Kjustendil', 212);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('LV', 'Loveč', 212);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('MN', 'Montana', 212);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('PA', 'Pazardžik', 212);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('PD', 'Plovdiv', 212);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('PK', 'Pernik', 212);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('PL', 'Pleven', 212);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('RS', 'Ruse', 212);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('RZ', 'Razgrad', 212);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('SF', 'Sofija', 212);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('SL', 'Sliven', 212);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('SM', 'Smoljan', 212);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('SN', 'Šumen', 212);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('SO', 'Sofija Grad', 212);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('SS', 'Silistra', 212);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('SZ', 'Stara Zagora', 212);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('TA', 'Tărgovište', 212);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('VD', 'Vidin', 212);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('VN', 'Varna', 212);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('VR', 'Vraca', 212);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('VT', 'Veliko Tărnovo', 212);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('YA', 'Yambol', 212);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('2A', 'Corse-du-Sud', 214);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('2B', 'Haute-Corse', 214);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('015', 'Koebenhavns amt', 221);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('020', 'Frederiksborg amt', 221);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('025', 'Roskilde amt', 221);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('030', 'Vestsjaellands amt', 221);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('035', 'Storstrøm amt', 221);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('040', 'Bornholms amt', 221);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('042', 'Fyns amt', 221);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('050', 'Sínderjylland amt', 221);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('055', 'Ribe amt', 221);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('060', 'Vejle amt', 221);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('065', 'Ringkøbing amt', 221);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('070', 'Århus amt', 221);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('076', 'Viborg amt', 221);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('080', 'Nordjyllands amt', 221);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('101', 'Copenhagen City', 221);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('147', 'Frederiksberg', 221);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('100', 'Somero', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('102', 'Alastaro', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('103', 'Askainen', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('104', 'Aura', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('105', 'Dragsfjärd', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('106', 'Eura', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('107', 'Eurajoki', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('108', 'Halikko', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('109', 'Harjavalta', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('110', 'Honkajoki', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('111', 'Houtskari', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('112', 'Huittinen', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('115', 'Iniö', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('116', 'Jämijärvi', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('117', 'Kaarina', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('119', 'Kankaanpää', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('120', 'Karinainen', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('122', 'Karvia', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('123', 'Äetsä', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('124', 'Kemiö', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('126', 'Kiikala', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('128', 'Kiikoinen', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('129', 'Kisko', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('130', 'Kiukainen', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('131', 'Kodisjoki', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('132', 'Kokemäki', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('133', 'Korppoo', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('134', 'Koski tl', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('135', 'Kullaa', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('136', 'Kustavi', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('137', 'Kuusjoki', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('138', 'Köyliö', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('139', 'Laitila', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('140', 'Lappi', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('141', 'Lavia', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('142', 'Lemu', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('143', 'Lieto', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('144', 'Loimaa', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('145', 'Loimaan kunta', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('147', 'Luvia', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('148', 'Marttila', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('149', 'Masku', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('150', 'Mellilä', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('151', 'Merikarvia', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('152', 'Merimasku', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('154', 'Mietoinen', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('156', 'Muurla', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('157', 'Mynämäki', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('158', 'Naantali', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('159', 'Nakkila', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('160', 'Nauvo', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('161', 'Noormarkku', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('162', 'Nousiainen', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('163', 'Oripää', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('164', 'Paimio', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('165', 'Parainen', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('167', 'Perniö', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('168', 'Pertteli', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('169', 'Piikkiö', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('170', 'Pomarkku', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('171', 'Pori', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('172', 'Punkalaidun', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('173', 'Pyhäranta', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('174', 'Pöytyä', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('175', 'Raisio', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('176', 'Rauma', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('178', 'Rusko', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('179', 'Rymättylä', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('180', 'Salo', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('181', 'Sauvo', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('182', 'Siikainen', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('183', 'Suodenniemi', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('184', 'Suomusjärvi', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('185', 'Säkylä', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('186', 'Särkisalo', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('187', 'Taivassalo', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('188', 'Tarvasjoki', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('189', 'Turku', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('190', 'Ulvila', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('191', 'Uusikaupunki', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('192', 'Vahto', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('193', 'Vammala', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('194', 'Vampula', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('195', 'Vehmaa', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('196', 'Velkua', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('198', 'Västanfjärd', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('199', 'Yläne', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('201', 'Artjärvi', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('202', 'Askola', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('204', 'Espoo', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('205', 'Hanko', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('206', 'Helsinki', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('207', 'Hyvinkää', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('208', 'Inkoo', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('209', 'Järvenpää', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('210', 'Karjaa', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('211', 'Karjalohja', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('212', 'Karkkila', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('213', 'Kauniainen', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('214', 'Kerava', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('215', 'Kirkkonummi', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('216', 'Lapinjärvi', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('217', 'Liljendal', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('218', 'Lohjan kaupunki', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('220', 'Loviisa', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('221', 'Myrskylä', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('222', 'Mäntsälä', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('223', 'Nummi-Pusula', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('224', 'Nurmijärvi', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('225', 'Orimattila', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('226', 'Pernaja', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('227', 'Pohja', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('228', 'Pornainen', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('229', 'Porvoo', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('231', 'Pukkila', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('233', 'Ruotsinpyhtää', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('234', 'Sammatti', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('235', 'Sipoo', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('236', 'Siuntio', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('238', 'Tammisaari', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('241', 'Tuusula', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('242', 'Vantaa', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('243', 'Vihti', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('301', 'Asikkala', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('303', 'Forssa', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('304', 'Hattula', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('305', 'Hauho', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('306', 'Hausjärvi', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('307', 'Hollola', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('308', 'Humppila', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('309', 'Hämeenlinna', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('310', 'Janakkala', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('311', 'Jokioinen', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('312', 'Juupajoki', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('313', 'Kalvola', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('314', 'Kangasala', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('315', 'Hämeenkoski', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('316', 'Kuhmalahti', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('318', 'Kuru', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('319', 'Kylmäkoski', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('320', 'Kärkölä', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('321', 'Lahti', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('322', 'Lammi', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('323', 'Lempäälä', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('324', 'Loppi', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('325', 'Luopioinen', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('326', 'Längelmäki', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('327', 'Mänttä', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('328', 'Nastola', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('329', 'Nokia', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('330', 'Orivesi', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('331', 'Padasjoki', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('332', 'Pirkkala', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('333', 'Pälkäne', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('334', 'Renko', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('335', 'Riihimäki', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('336', 'Ruovesi', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('337', 'Sahalahti', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('340', 'Tammela', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('341', 'Tampere', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('342', 'Toijala', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('344', 'Tuulos', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('345', 'Urjala', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('346', 'Valkeakoski', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('347', 'Vesilahti', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('348', 'Viiala', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('349', 'Vilppula', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('350', 'Virrat', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('351', 'Ylöjärvi', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('352', 'Ypäjä', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('353', 'Hämeenkyrö', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('354', 'Ikaalinen', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('355', 'Kihniö', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('356', 'Mouhijärvi', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('357', 'Parkano', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('358', 'Viljakkala', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('402', 'Enonkoski', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('403', 'Hartola', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('404', 'Haukivuori', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('405', 'Heinola', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('407', 'Heinävesi', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('408', 'Hirvensalmi', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('409', 'Joroinen', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('410', 'Juva', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('411', 'Jäppilä', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('412', 'Kangaslampi', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('413', 'Kangasniemi', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('414', 'Kerimäki', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('415', 'Mikkeli', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('417', 'Mäntyharju', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('418', 'Pertunmaa', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('419', 'Pieksämäki', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('420', 'Pieksänmaa', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('421', 'Punkaharju', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('422', 'Puumala', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('423', 'Rantasalmi', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('424', 'Ristiina', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('425', 'Savonlinna', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('426', 'Savonranta', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('427', 'Sulkava', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('428', 'Sysmä', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('502', 'Elimäki', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('503', 'Hamina', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('504', 'Iitti', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('505', 'Imatra', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('506', 'Jaala', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('507', 'Joutseno', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('509', 'Kotka', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('510', 'Kouvola', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('511', 'Kuusankoski', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('513', 'Lappeenranta', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('514', 'Lemi', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('515', 'Luumäki', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('516', 'Miehikkälä', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('518', 'Parikkala', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('519', 'Pyhtää', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('520', 'Rautjärvi', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('521', 'Ruokolahti', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('522', 'Saari', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('523', 'Savitaipale', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('525', 'Suomenniemi', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('526', 'Taipalsaari', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('527', 'Uukuniemi', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('528', 'Valkeala', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('530', 'Virolahti', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('531', 'Ylämaa', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('532', 'Anjalankoski', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('601', 'Alahärmä', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('602', 'Alajärvi', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('603', 'Alavus', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('604', 'Evijärvi', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('605', 'Halsua', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('606', 'Hankasalmi', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('607', 'Himanka', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('608', 'Ilmajoki', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('609', 'Isojoki', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('610', 'Isokyrö', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('611', 'Jalasjärvi', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('612', 'Joutsa', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('613', 'Jurva', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('614', 'Jyväskylä', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('615', 'Jyväskylän mlk', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('616', 'Jämsä', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('617', 'Jämsänkoski', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('619', 'Kannonkoski', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('620', 'Kannus', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('621', 'Karijoki', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('622', 'Karstula', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('623', 'Kaskinen', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('624', 'Kauhajoki', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('625', 'Kauhava', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('626', 'Kaustinen', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('627', 'Keuruu', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('628', 'Kinnula', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('629', 'Kivijärvi', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('630', 'Kokkola', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('632', 'Konnevesi', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('633', 'Korpilahti', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('634', 'Korsnäs', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('635', 'Kortesjärvi', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('636', 'Kristiinankaupunki', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('637', 'Kruunupyy', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('638', 'Kuhmoinen', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('639', 'Kuortane', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('640', 'Kurikka', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('641', 'Kyyjärvi', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('642', 'Kälviä', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('643', 'Laihia', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('644', 'Lappajärvi', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('645', 'Lapua', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('646', 'Laukaa', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('647', 'Lehtimäki', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('648', 'Leivonmäki', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('649', 'Lestijärvi', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('650', 'Lohtaja', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('651', 'Luhanka', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('652', 'Luoto', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('653', 'Maalahti', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('654', 'Maksamaa', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('655', 'Multia', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('656', 'Mustasaari', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('657', 'Muurame', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('658', 'Nurmo', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('659', 'Närpiö', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('660', 'Oravainen', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('661', 'Perho', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('662', 'Peräseinäjoki', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('663', 'Petäjävesi', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('664', 'Pietarsaari', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('665', 'Pedersöre', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('666', 'Pihtipudas', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('668', 'Pylkönmäki', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('669', 'Saarijärvi', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('670', 'Seinäjoki', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('671', 'Soini', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('672', 'Sumiainen', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('673', 'Suolahti', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('675', 'Teuva', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('676', 'Toholampi', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('677', 'Toivakka', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('678', 'Töysä', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('679', 'Ullava', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('680', 'Uurainen', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('681', 'Uusikaarlepyy', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('682', 'Vaasa', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('683', 'Veteli', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('684', 'Viitasaari', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('685', 'Vimpeli', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('686', 'Vähäkyrö', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('687', 'Vöyri', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('688', 'Ylihärmä', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('689', 'Ylistaro', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('690', 'Ähtäri', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('692', 'Äänekoski', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('701', 'Eno', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('702', 'Iisalmi', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('703', 'Ilomantsi', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('704', 'Joensuu', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('705', 'Juankoski', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('706', 'Juuka', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('707', 'Kaavi', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('708', 'Karttula', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('709', 'Keitele', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('710', 'Kesälahti', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('711', 'Kiihtelysvaara', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('712', 'Kitee', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('713', 'Kiuruvesi', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('714', 'Kontiolahti', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('715', 'Kuopio', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('716', 'Lapinlahti', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('717', 'Leppävirta', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('718', 'Lieksa', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('719', 'Liperi', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('720', 'Maaninka', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('721', 'Nilsiä', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('722', 'Nurmes', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('723', 'Outokumpu', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('724', 'Pielavesi', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('725', 'Polvijärvi', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('726', 'Pyhäselkä', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('727', 'Rautalampi', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('728', 'Rautavaara', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('729', 'Rääkkylä', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('730', 'Siilinjärvi', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('731', 'Sonkajärvi', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('732', 'Suonenjoki', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('733', 'Tervo', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('734', 'Tohmajärvi', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('735', 'Tuupovaara', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('736', 'Tuusniemi', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('737', 'Valtimo', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('738', 'Varkaus', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('739', 'Varpaisjärvi', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('740', 'Vehmersalmi', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('741', 'Vesanto', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('742', 'Vieremä', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('743', 'Värtsilä', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('801', 'Alavieska', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('802', 'Haapajärvi', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('803', 'Haapavesi', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('804', 'Hailuoto', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('805', 'Haukipudas', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('806', 'Hyrynsalmi', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('807', 'Ii', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('808', 'Kajaani', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('810', 'Kalajoki', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('811', 'Kempele', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('812', 'Kestilä', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('813', 'Kiiminki', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('814', 'Kuhmo', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('815', 'Kuivaniemi', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('816', 'Kuusamo', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('817', 'Kärsämäki', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('818', 'Liminka', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('819', 'Lumijoki', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('820', 'Merijärvi', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('821', 'Muhos', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('822', 'Nivala', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('823', 'Oulainen', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('824', 'Oulu', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('825', 'Oulunsalo', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('826', 'Paltamo', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('827', 'Pattijoki', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('828', 'Piippola', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('829', 'Pudasjärvi', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('830', 'Pulkkila', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('831', 'Puolanka', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('832', 'Pyhäjoki', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('833', 'Pyhäjärvi', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('834', 'Pyhäntä', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('835', 'Raahe', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('836', 'Rantsila', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('837', 'Reisjärvi', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('838', 'Ristijärvi', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('839', 'Ruukki', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('840', 'Sievi', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('841', 'Siikajoki', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('842', 'Sotkamo', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('843', 'Suomussalmi', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('844', 'Taivalkoski', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('846', 'Tyrnävä', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('847', 'Utajärvi', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('848', 'Vaala', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('849', 'Vihanti', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('850', 'Vuolijoki', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('851', 'Yli-Ii', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('852', 'Ylikiiminki', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('853', 'Ylivieska', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('901', 'Enontekiö', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('902', 'Inari', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('903', 'Kemi', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('904', 'Keminmaa', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('905', 'Kemijärvi', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('907', 'Kittilä', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('908', 'Kolari', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('909', 'Muonio', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('910', 'Pelkosenniemi', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('911', 'Pello', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('912', 'Posio', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('913', 'Ranua', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('914', 'Rovaniemi', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('915', 'Rovaniemen mlk', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('916', 'Salla', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('917', 'Savukoski', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('918', 'Simo', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('919', 'Sodankylä', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('920', 'Tervola', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('921', 'Tornio', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('922', 'Utsjoki', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('923', 'Ylitornio', 224);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('CA', 'Cagliari', 225);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('CI', 'Carbonia-Iglesias', 225);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('MD', 'Medio Campidano', 225);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('NU', 'Nuoro', 225);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('OG', 'Ogliastra', 225);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('OR', 'Oristano', 225);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('OT', 'Olbia-Tempio', 225);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('SS', 'Sassari', 225);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('SU', 'Sud Sardegna', 225);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('VS', 'MedioCampidano', 225);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('01', 'Ain', 227);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('02', 'Aisne', 227);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('03', 'Allier', 227);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('04', 'Alpes-de-Haute-Provence', 227);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('05', 'Hautes-Alpes', 227);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('06', 'Alpes-Maritimes', 227);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('07', 'Ardèche', 227);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('08', 'Ardennes', 227);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('09', 'Ariège', 227);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('10', 'Aube', 227);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('11', 'Aude', 227);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('12', 'Aveyron', 227);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('13', 'Bouches-du-Rhône', 227);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('14', 'Calvados', 227);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('15', 'Cantal', 227);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('16', 'Charente', 227);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('17', 'Charente-Maritime', 227);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('18', 'Cher', 227);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('19', 'Corrèze', 227);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('21', 'Côte-d''Or', 227);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('22', 'Côtes-d''Armor', 227);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('23', 'Creuse', 227);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('24', 'Dordogne', 227);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('25', 'Doubs', 227);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('26', 'Drôme', 227);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('27', 'Eure', 227);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('28', 'Eure-et-Loir', 227);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('29', 'Finistère', 227);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('30', 'Gard', 227);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('31', 'Haute-Garonne', 227);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('32', 'Gers', 227);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('33', 'Gironde', 227);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('34', 'Hérault', 227);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('35', 'Ille-et-Vilaine', 227);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('36', 'Indre', 227);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('37', 'Indre-et-Loire', 227);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('38', 'Isère', 227);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('39', 'Jura', 227);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('40', 'Landes', 227);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('41', 'Loir-et-Cher', 227);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('42', 'Loire', 227);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('43', 'Haute-Loire', 227);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('44', 'Loire-Atlantique', 227);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('45', 'Loiret', 227);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('46', 'Lot', 227);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('47', 'Lot-et-Garonne', 227);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('48', 'Lozère', 227);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('49', 'Maine-et-Loire', 227);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('50', 'Manche', 227);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('51', 'Marne', 227);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('52', 'Haute-Marne', 227);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('53', 'Mayenne', 227);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('54', 'Meurthe-et-Moselle', 227);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('55', 'Meuse', 227);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('56', 'Morbihan', 227);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('57', 'Moselle', 227);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('58', 'Nièvre', 227);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('59', 'Nord', 227);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('60', 'Oise', 227);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('61', 'Orne', 227);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('62', 'Pas-de-Calais', 227);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('63', 'Puy-de-Dôme', 227);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('64', 'Pyrénées-Atlantiques', 227);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('65', 'Hautes-Pyrénées', 227);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('66', 'Pyrénées-Orientales', 227);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('67', 'Bas-Rhin', 227);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('68', 'Haut-Rhin', 227);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('69', 'Rhône', 227);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('70', 'Haute-Saône', 227);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('71', 'Saône-et-Loire', 227);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('72', 'Sarthe', 227);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('73', 'Savoie', 227);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('74', 'Haute-Savoie', 227);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('75', 'Paris', 227);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('76', 'Seine-Maritime', 227);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('77', 'Seine-et-Marne', 227);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('78', 'Yvelines', 227);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('79', 'Deux-Sèvres', 227);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('80', 'Somme', 227);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('81', 'Tarn', 227);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('82', 'Tarn-et-Garonne', 227);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('83', 'Var', 227);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('84', 'Vaucluse', 227);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('85', 'Vendée', 227);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('86', 'Vienne', 227);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('87', 'Haute-Vienne', 227);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('88', 'Vosges', 227);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('89', 'Yonne', 227);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('90', 'Territoire de Belfort', 227);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('91', 'Essonne', 227);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('92', 'Hauts-de-Seine', 227);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('93', 'Seine-Saint-Denis', 227);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('94', 'Val-de-Marne', 227);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('95', 'Val-d''Oise', 227);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('BB', 'Brandenburg', 230);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('BE', 'Berlin', 230);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('BW', 'Baden-Württemberg', 230);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('BY', 'Bayern', 230);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('HB', 'Bremen', 230);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('HE', 'Hessen', 230);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('HH', 'Hamburg', 230);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('MV', 'Mecklenburg-Vorpommern', 230);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('NI', 'Niedersachsen', 230);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('NW', 'Nordrhein-Westfalen', 230);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('RP', 'Rheinland-Pfalz', 230);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('SH', 'Schleswig-Holstein', 230);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('SL', 'Saarland', 230);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('SN', 'Sachsen', 230);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('ST', 'Sachsen-Anhalt', 230);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('TH', 'Thüringen', 230);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('BA', 'Baranya', 239);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('BE', 'Békés', 239);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('BN', 'Bács-Kiskun', 239);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('BO', 'Borsod', 239);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('BP', 'Budapest', 239);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('CS', 'Csongrád', 239);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('FE', 'Fejér', 239);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('GY', 'Gyõr', 239);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('HB', 'Hajdú-Bihar', 239);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('HE', 'Heves', 239);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('KO', 'Komárom', 239);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('NG', 'Nógrád', 239);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('PE', 'Pest', 239);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('SA', 'Szabolcs', 239);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('SO', 'Somogy', 239);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('SZ', 'Szolnok', 239);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('TO', 'Tolna', 239);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('VA', 'Vas', 239);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('VE', 'Veszprém', 239);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('ZA', 'Zala', 239);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('C', 'Cork', 245);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('CE', 'Clare', 245);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('CN', 'Cavan', 245);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('CO', 'Cork', 245);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('CW', 'Carlow', 245);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('D', 'Dublin', 245);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('DL', 'Donegal', 245);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('G', 'Galway', 245);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('KE', 'Kildare', 245);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('KK', 'Kilkenny', 245);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('KY', 'Kerry', 245);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('LD', 'Longford', 245);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('LH', 'Louth', 245);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('LK', 'Limerick', 245);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('LM', 'Leitrim', 245);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('LS', 'Laois', 245);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('MH', 'Meath', 245);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('MN', 'Monaghan', 245);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('MO', 'Mayo', 245);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('OY', 'Offaly', 245);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('RN', 'Roscommon', 245);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('SO', 'Sligo', 245);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('TA', 'Tipperary', 245);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('WD', 'Waterford', 245);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('WH', 'Westmeath', 245);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('WW', 'Wicklow', 245);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('WX', 'Wexford', 245);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('AG', 'Agrigento', 248);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('AL', 'Alessandria', 248);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('AN', 'Ancona', 248);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('AO', 'Aosta', 248);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('AP', 'Ascoli Piceno', 248);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('AQ', 'L''Aquila', 248);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('AR', 'Arezzo', 248);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('AT', 'Asti', 248);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('AV', 'Avellino', 248);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('BA', 'Bari', 248);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('BG', 'Bergamo', 248);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('BI', 'Biella', 248);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('BL', 'Belluno', 248);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('BN', 'Benevento', 248);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('BO', 'Bologna', 248);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('BR', 'Brindisi', 248);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('BS', 'Brescia', 248);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('BT', 'Barletta-Andria-Trani', 248);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('BZ', 'Bolzano', 248);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('CB', 'Campobasso', 248);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('CE', 'Caserta', 248);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('CH', 'Chieti', 248);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('CL', 'Caltanissetta', 248);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('CN', 'Cuneo', 248);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('CO', 'Como', 248);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('CR', 'Cremona', 248);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('CS', 'Cosenza', 248);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('CT', 'Catania', 248);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('CZ', 'Catanzaro', 248);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('EN', 'Enna', 248);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('FC', 'Forlì-Cesena', 248);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('FE', 'Ferrara', 248);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('FG', 'Foggia', 248);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('FI', 'Firenze', 248);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('FM', 'Fermo', 248);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('FO', 'Forlì', 248);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('FR', 'Frosinone', 248);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('GE', 'Genova', 248);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('GO', 'Gorizia', 248);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('GR', 'Grosseto', 248);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('IM', 'Imperia', 248);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('IS', 'Isernia', 248);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('KR', 'Crotone', 248);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('LC', 'Lecco', 248);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('LE', 'Lecce', 248);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('LI', 'Livorno', 248);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('LO', 'Lodi', 248);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('LT', 'Latina', 248);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('LU', 'Lucca', 248);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('MB', 'Monza e Brianza', 248);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('MC', 'Macerata', 248);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('ME', 'Messina', 248);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('MI', 'Milano', 248);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('MN', 'Mantova', 248);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('MO', 'Modena', 248);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('MS', 'Massa Carrara', 248);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('MT', 'Matera', 248);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('NA', 'Napoli', 248);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('NO', 'Novara', 248);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('PA', 'Palermo', 248);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('PC', 'Piacenza', 248);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('PD', 'Padova', 248);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('PE', 'Pescara', 248);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('PG', 'Perugia', 248);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('PI', 'Pisa', 248);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('PN', 'Pordenone', 248);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('PO', 'Prato', 248);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('PR', 'Parma', 248);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('PS', 'Pesaro e Urbino', 248);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('PT', 'Pistoia', 248);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('PU', 'Pesaro e Urbino', 248);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('PV', 'Pavia', 248);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('PZ', 'Potenza', 248);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('RA', 'Ravenna', 248);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('RC', 'Reggio Calabria', 248);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('RE', 'Reggio Emilia', 248);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('RG', 'Ragusa', 248);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('RI', 'Rieti', 248);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('RM', 'Roma', 248);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('RN', 'Rimini', 248);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('RO', 'Rovigo', 248);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('SA', 'Salerno', 248);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('SI', 'Siena', 248);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('SO', 'Sondrio', 248);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('SP', 'La Spezia', 248);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('SR', 'Siracusa', 248);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('SV', 'Savona', 248);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('TA', 'Taranto', 248);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('TE', 'Teramo', 248);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('TN', 'Trento', 248);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('TO', 'Torino', 248);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('TP', 'Trapani', 248);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('TR', 'Terni', 248);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('TS', 'Trieste', 248);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('TV', 'Treviso', 248);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('UD', 'Udine', 248);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('VA', 'Varese', 248);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('VB', 'Verbano Cusio Ossola', 248);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('VC', 'Vercelli', 248);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('VE', 'Venezia', 248);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('VI', 'Vicenza', 248);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('VR', 'Verona', 248);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('VT', 'Viterbo', 248);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('VV', 'Vibo Valentia', 248);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('MD', 'Madeira', 256);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('21', 'Svalbard', 259);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('DR', 'Drenthe', 263);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('FL', 'Flevoland', 263);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('FR', 'Fryslân', 263);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('GD', 'Gelderland', 263);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('GE', 'Gelderland', 263);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('GR', 'Groningen', 263);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('LB', 'Limburg', 263);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('LI', 'Limburg', 263);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('NB', 'Noord-Brabant', 263);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('NH', 'Noord-Holland', 263);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('OV', 'Overijssel', 263);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('UT', 'Utrecht', 263);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('ZE', 'Zeeland', 263);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('ZH', 'Zuid-Holland', 263);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('ZL', 'Zeeland', 263);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('03', 'Oslo', 266);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('11', 'Rogaland', 266);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('15', 'Møre og Romsdal', 266);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('18', 'Nordland', 266);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('30', 'Viken', 266);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('34', 'Innlandet', 266);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('38', 'Vestfold og Telemark', 266);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('42', 'Agder', 266);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('46', 'Vestland', 266);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('50', 'Trøndelag', 266);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('54', 'Troms og Finnmark', 266);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('B', 'Lubuskie', 269);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('C', 'Lodzkie', 269);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('D', 'Dolnoslaskie', 269);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('F', 'Pomorskie', 269);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('G', 'Slaskie', 269);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('J', 'Warminsko-Mazurskie', 269);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('K', 'Podkarpackie', 269);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('L', 'Lubelskie', 269);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('M', 'Malopolskie', 269);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('O', 'Podlaskie', 269);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('P', 'Kujawsko-Pomorskie', 269);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('R', 'Mazowieckie', 269);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('S', 'Swietokrzyskie', 269);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('U', 'Opolskie', 269);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('W', 'Wielkopolskie', 269);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('Z', 'Zachodnio-Pomorskie', 269);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('AV', 'Aveiro', 272);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('BG', 'Bragança', 272);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('BJ', 'Beja', 272);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('BR', 'Braga', 272);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('CB', 'Castelo Branco', 272);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('CO', 'Coimbra', 272);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('EV', 'Evora', 272);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('FR', 'Faro', 272);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('GD', 'Guarda', 272);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('LR', 'Leiria', 272);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('LX', 'Lisboa', 272);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('PG', 'Portalegre', 272);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('PT', 'Porto', 272);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('SR', 'Santarem', 272);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('ST', 'Setubal', 272);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('VC', 'Viana do Castelo', 272);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('VR', 'Vila Real', 272);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('VS', 'Viseu', 272);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('AB', 'Alba', 275);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('AG', 'Argeș', 275);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('AR', 'Arad', 275);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('B', 'București', 275);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('BC', 'Bacău', 275);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('BH', 'Bihor', 275);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('BN', 'Bistrița-Năsăud', 275);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('BR', 'Brăila', 275);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('BT', 'Botoșani', 275);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('BU', 'Bucureşti', 275);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('BV', 'Brașov', 275);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('BZ', 'Buzău', 275);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('CJ', 'Cluj', 275);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('CL', 'Călărași', 275);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('CS', 'Caraș-Severin', 275);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('CT', 'Constanța', 275);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('CV', 'Covasna', 275);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('DB', 'Dâmbovița', 275);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('DJ', 'Dolj', 275);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('GJ', 'Gorj', 275);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('GL', 'Galați', 275);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('GR', 'Giurgiu', 275);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('HD', 'Hunedoara', 275);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('HR', 'Harghita', 275);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('IF', 'Ilfov', 275);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('IL', 'Ialomița', 275);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('IS', 'Iași', 275);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('MH', 'Mehedinți', 275);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('MM', 'Maramureș', 275);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('MS', 'Mureș', 275);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('NT', 'Neamț', 275);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('OT', 'Olt', 275);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('PH', 'Prahova', 275);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('SB', 'Sibiu', 275);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('SJ', 'Sălaj', 275);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('SM', 'Satu Mare', 275);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('SV', 'Suceava', 275);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('TL', 'Tulcea', 275);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('TM', 'Timiș', 275);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('TR', 'Teleorman', 275);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('VL', 'Vâlcea', 275);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('VN', 'Vrancea', 275);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('VS', 'Vaslui', 275);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('A', 'Alicante', 281);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('AB', 'Albacete', 281);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('AL', 'Almeria', 281);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('AV', 'Ávila', 281);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('B', 'Barcelona', 281);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('BA', 'Badajoz', 281);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('BI', 'Bizkaia', 281);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('BU', 'Burgos', 281);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('C', 'A Coruña', 281);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('CA', 'Cádiz', 281);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('CC', 'Cáceres', 281);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('CO', 'Córdoba', 281);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('CR', 'Ciudad Real', 281);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('CS', 'Castellón', 281);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('CU', 'Cuenca', 281);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('GI', 'Girona', 281);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('GR', 'Granada', 281);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('GU', 'Guadalajara', 281);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('H', 'Huelva', 281);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('HU', 'Huesca', 281);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('J', 'Jaén', 281);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('L', 'Lleida', 281);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('LE', 'León', 281);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('LO', 'La Rioja', 281);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('LU', 'Lugo', 281);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('M', 'Madrid', 281);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('MA', 'Málaga', 281);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('MU', 'Murcia', 281);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('NA', 'Navarra', 281);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('O', 'Asturias', 281);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('OR', 'Ourense', 281);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('OU', 'Ourense', 281);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('P', 'Palencia', 281);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('PO', 'Pontevedra', 281);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('S', 'Cantabria', 281);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('SA', 'Salamanca', 281);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('SE', 'Sevilla', 281);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('SG', 'Segovia', 281);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('SO', 'Soria', 281);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('SS', 'Gipuzkoa', 281);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('T', 'Tarragona', 281);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('TE', 'Teruel', 281);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('TO', 'Toledo', 281);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('V', 'València', 281);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('VA', 'Valladolid', 281);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('VI', 'Álava', 281);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('Z', 'Zaragoza', 281);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('ZA', 'Zamora', 281);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('AB', 'Stockholms län', 284);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('AC', 'Västerbottens län', 284);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('BD', 'Norrbottens län', 284);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('C', 'Uppsala län', 284);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('D', 'Södermanlands län', 284);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('E', 'Östergötlands län', 284);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('F', 'Jönköpings län', 284);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('G', 'Kronobergs län', 284);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('H', 'Kalmar län', 284);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('I', 'Gotlands län', 284);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('K', 'Blekinge län', 284);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('M', 'Skåne län', 284);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('N', 'Hallands län', 284);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('O', 'Västra Götalands län', 284);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('S', 'Värmlands län', 284);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('T', 'Örebro län', 284);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('U', 'Västmanlands län', 284);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('W', 'Dalarnas län', 284);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('X', 'Gävleborgs län', 284);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('Y', 'Västernorrlands län', 284);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('Z', 'Jämtlands län', 284);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('AG', 'Aargau', 287);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('AI', 'Appenzell Innerrhoden', 287);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('AR', 'Appenzell Ausserrhoden', 287);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('BE', 'Bern', 287);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('BL', 'Basel Landschaft', 287);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('BS', 'Basel Stadt', 287);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('FR', 'Freiburg / Fribourg', 287);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('GE', 'Genf / Genève', 287);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('GL', 'Glarus', 287);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('GR', 'Graubuenden / Grisons', 287);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('JU', 'Jura', 287);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('LU', 'Luzern', 287);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('NE', 'Neuenburg / Neuchâtel', 287);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('NW', 'Nidwalden', 287);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('OW', 'Obwalden', 287);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('SG', 'St. Gallen', 287);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('SH', 'Schaffhausen', 287);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('SO', 'Solothurn', 287);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('SZ', 'Schwyz', 287);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('TG', 'Thurgau', 287);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('TI', 'Tessin / Ticino', 287);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('UR', 'Uri', 287);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('VD', 'Waadt / Vaud', 287);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('VS', 'Wallis / Valais', 287);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('ZG', 'Zug', 287);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('ZH', 'Zuerich', 287);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('CH', 'Cherkas''ka Oblast''', 288);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('CN', 'Chernivets''ka Oblast''', 288);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('CR', 'Chernihivs''ka Oblast''', 288);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('DN', 'Dnipropetrovs''ka Oblast''', 288);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('DO', 'Donets''ka Oblast''', 288);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('HA', 'Kharkivs''ka Oblast''', 288);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('HE', 'Khersons''ka Oblast''', 288);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('HM', 'Khmel''nyts''ka Oblast''', 288);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('IF', 'Ivano-Frankivs''ka Oblast''', 288);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('KI', 'Kirovohrads''ka Oblast''', 288);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('KO', 'Kyivs''ka Oblast''', 288);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('KR', 'Respublika Krym', 288);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('KV', 'Kyïv', 288);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('LU', 'Luhans''ka Oblast''', 288);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('LV', 'L''vivs''ka Oblast''', 288);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('NI', 'Mykolaivs''ka Oblast''', 288);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('OD', 'Odes''ka Oblast''', 288);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('PO', 'Poltavs''ka Oblast''', 288);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('RI', 'Rivnens''ka Oblast''', 288);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('SL', 'Sevastopol''', 288);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('SU', 'Sums''ka Oblast''', 288);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('TE', 'Ternopil''s''ka Oblast''', 288);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('VI', 'Vinnyts''ka Oblast''', 288);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('VO', 'Volyos''ka Oblast''', 288);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('ZA', 'Zakarpats''ka Oblast''', 288);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('ZH', 'Zhytomyrs''ka Oblast''', 288);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('ZP', 'Zaporiz''ka Oblast''', 288);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('AL', 'Alabama', 291);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('AR', 'Arkansas', 291);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('AZ', 'Arizona', 291);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('CA', 'California', 291);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('CO', 'Colorado', 291);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('CT', 'Connecticut', 291);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('DC', 'District of Columbia', 291);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('DE', 'Delaware', 291);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('FL', 'Florida', 291);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('GA', 'Georgia', 291);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('IA', 'Iowa', 291);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('ID', 'Idaho', 291);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('IL', 'Illinois', 291);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('IN', 'Indiana', 291);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('KS', 'Kansas', 291);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('KY', 'Kentucky', 291);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('LA', 'Louisiana', 291);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('MA', 'Massachusetts', 291);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('MD', 'Maryland', 291);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('ME', 'Maine', 291);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('MI', 'Michigan', 291);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('MN', 'Minnesota', 291);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('MO', 'Missouri', 291);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('MS', 'Mississippi', 291);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('MT', 'Montana', 291);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('NC', 'North Carolina', 291);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('ND', 'North Dakota', 291);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('NE', 'Nebraska', 291);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('NH', 'New Hampshire', 291);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('NJ', 'New Jersey', 291);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('NM', 'New Mexico', 291);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('NV', 'Nevada', 291);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('NY', 'New York', 291);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('OH', 'Ohio', 291);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('OK', 'Oklahoma', 291);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('OR', 'Oregon', 291);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('PA', 'Pennsylvania', 291);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('RI', 'Rhode Island', 291);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('SC', 'South Carolina', 291);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('SD', 'South Dakota', 291);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('TN', 'Tennessee', 291);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('TX', 'Texas', 291);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('UT', 'Utah', 291);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('VA', 'Virginia', 291);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('VT', 'Vermont', 291);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('WA', 'Washington', 291);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('WI', 'Wisconsin', 291);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('WV', 'West Virginia', 291);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('WY', 'Wyoming', 291);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('AH', 'Anhui', 318);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('BJ', 'Beijing', 318);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('CQ', 'Chongqing', 318);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('FJ', 'Fujian', 318);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('GD', 'Guangdong', 318);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('GS', 'Gansu', 318);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('GX', 'Guangxi Zhuangzu', 318);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('GZ', 'Guizhou', 318);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('HA', 'Henan', 318);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('HB', 'Hubei', 318);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('HE', 'Hebei', 318);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('HI', 'Hainan', 318);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('HL', 'Heilongjiang', 318);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('HN', 'Hunan', 318);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('JL', 'Jilin', 318);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('JS', 'Jiangsu', 318);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('JX', 'Jiangxi', 318);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('LN', 'Liaoning', 318);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('NM', 'Nei Mongol', 318);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('NX', 'Ningxia Huizu', 318);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('QH', 'Qinghai', 318);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('SC', 'Sichuan', 318);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('SD', 'Shandong', 318);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('SH', 'Shanghai', 318);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('SN', 'Shaanxi', 318);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('SX', 'Shanxi', 318);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('TJ', 'Tianjin', 318);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('XJ', 'Xinjiang Uygur', 318);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('XZ', 'Xizang', 318);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('YN', 'Yunnan', 318);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('ZJ', 'Zhejiang', 318);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('AP', 'Andhra Pradesh', 324);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('AR', 'Arunāchal Pradesh', 324);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('AS', 'Assam', 324);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('BR', 'Bihār', 324);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('CG', 'Chhattīsgarh', 324);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('CH', 'Chandīgarh', 324);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('DD', 'Damān and Diu', 324);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('DL', 'Delhi', 324);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('DN', 'Dādra and Nagar Haveli', 324);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('GA', 'Goa', 324);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('GJ', 'Gujarāt', 324);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('HP', 'Himāchal Pradesh', 324);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('HR', 'Haryāna', 324);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('JH', 'Jhārkhand', 324);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('JK', 'Jammu and Kashmīr', 324);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('KA', 'Karnātaka', 324);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('KL', 'Kerala', 324);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('LA', 'Ladākh', 324);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('MH', 'Mahārāshtra', 324);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('ML', 'Meghālaya', 324);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('MN', 'Manipur', 324);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('MP', 'Madhya Pradesh', 324);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('MZ', 'Mizoram', 324);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('NL', 'Nāgāland', 324);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('OD', 'Odisha', 324);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('PB', 'Punjab', 324);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('PY', 'Puducherry', 324);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('RJ', 'Rājasthān', 324);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('SK', 'Sikkim', 324);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('TG', 'Telangāna', 324);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('TN', 'Tamil Nādu', 324);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('TR', 'Tripura', 324);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('UK', 'Uttarākhand', 324);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('UP', 'Uttar Pradesh', 324);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('WB', 'West Bengal', 324);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('01', 'Hokkaido', 339);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('02', 'Aomori', 339);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('03', 'Iwate', 339);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('04', 'Akita', 339);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('05', 'Yamagata', 339);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('06', 'Miyagi', 339);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('07', 'Fukushima', 339);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('08', 'Niigata', 339);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('09', 'Nagano', 339);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('10', 'Tokyo', 339);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('11', 'Kanagawa', 339);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('12', 'Chiba', 339);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('13', 'Saitama', 339);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('14', 'Ibaraki', 339);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('15', 'Tochigi', 339);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('16', 'Gunma', 339);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('17', 'Yamanashi', 339);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('18', 'Shizuoka', 339);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('19', 'Gifu', 339);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('20', 'Aichi', 339);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('21', 'Mie', 339);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('22', 'Kyoto', 339);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('23', 'Shiga', 339);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('24', 'Nara', 339);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('25', 'Osaka', 339);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('26', 'Wakayama', 339);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('27', 'Hyogo', 339);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('28', 'Toyama', 339);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('29', 'Fukui', 339);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('30', 'Ishikawa', 339);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('31', 'Okayama', 339);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('32', 'Shimane', 339);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('33', 'Yamaguchi', 339);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('34', 'Tottori', 339);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('35', 'Hiroshima', 339);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('36', 'Kagawa', 339);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('37', 'Tokushima', 339);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('38', 'Ehime', 339);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('39', 'Kochi', 339);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('40', 'Fukuoka', 339);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('41', 'Saga', 339);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('42', 'Nagasaki', 339);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('43', 'Kumamoto', 339);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('44', 'Oita', 339);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('45', 'Miyazaki', 339);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('46', 'Kagoshima', 339);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('47', 'Okinawa', 339);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('ABR', 'Abra', 375);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('AGN', 'Agusan del Norte', 375);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('AGS', 'Agusan del Sur', 375);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('AKL', 'Aklan', 375);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('ALB', 'Albay', 375);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('ANT', 'Antique', 375);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('APA', 'Apayao', 375);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('AUR', 'Aurora', 375);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('BAN', 'Bataan', 375);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('BAS', 'Basilan', 375);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('BEN', 'Benguet', 375);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('BIL', 'Biliran', 375);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('BOH', 'Bohol', 375);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('BTG', 'Batangas', 375);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('BTN', 'Batanes', 375);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('BUK', 'Bukidnon', 375);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('BUL', 'Bulacan', 375);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('CAG', 'Cagayan', 375);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('CAM', 'Camiguin', 375);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('CAN', 'Camarines Norte', 375);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('CAP', 'Capiz', 375);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('CAS', 'Camarines Sur', 375);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('CAT', 'Catanduanes', 375);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('CAV', 'Cavite', 375);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('CEB', 'Cebu', 375);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('COM', 'Davao de Oro', 375);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('DAO', 'Davao Oriental', 375);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('DAS', 'Davao del Sur', 375);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('DAV', 'Davao del Norte', 375);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('EAS', 'Eastern Samar', 375);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('GUI', 'Guimaras', 375);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('IFU', 'Ifugao', 375);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('ILI', 'Iloilo', 375);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('ILN', 'Ilocos Norte', 375);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('ILS', 'Ilocos Sur', 375);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('ISA', 'Isabela', 375);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('KAL', 'Kalinga', 375);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('LAG', 'Laguna', 375);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('LAN', 'Lanao del Norte', 375);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('LAS', 'Lanao del Sur', 375);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('LEY', 'Leyte', 375);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('LUN', 'La Union', 375);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('MAD', 'Marinduque', 375);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('MAG', 'Maguindanao', 375);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('MAS', 'Masbate', 375);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('MDC', 'Mindoro Occidental', 375);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('MDR', 'Mindoro Oriental', 375);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('MOU', 'Mountain Province', 375);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('MSC', 'Misamis Occidental', 375);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('MSR', 'Misamis Oriental', 375);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('NCO', 'Cotabato', 375);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('NEC', 'Negros Occidental', 375);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('NER', 'Negros Oriental', 375);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('NSA', 'Northern Samar', 375);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('NUE', 'Nueva Ecija', 375);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('NUV', 'Nueva Vizcaya', 375);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('PAM', 'Pampanga', 375);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('PAN', 'Pangasinan', 375);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('PLW', 'Palawan', 375);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('QUE', 'Quezon', 375);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('QUI', 'Quirino', 375);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('RIZ', 'Rizal', 375);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('ROM', 'Romblon', 375);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('SAR', 'Sarangani', 375);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('SCO', 'South Cotabato', 375);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('SIG', 'Siquijor', 375);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('SLE', 'Southern Leyte', 375);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('SLU', 'Sulu', 375);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('SOR', 'Sorsogon', 375);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('SUK', 'Sultan Kudarat', 375);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('SUN', 'Surigao del Norte', 375);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('SUR', 'Surigao del Sur', 375);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('TAR', 'Tarlac', 375);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('TAW', 'Tawi-Tawi', 375);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('WSA', 'Western Samar', 375);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('ZAN', 'Zamboanga del Norte', 375);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('ZAS', 'Zamboanga del Sur', 375);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('ZMB', 'Zambales', 375);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('ZSI', 'Zamboanga Sibugay', 375);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('CHA', 'Changhua', 386);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('CYI', 'Chiayi', 386);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('CYQ', 'Chiayi', 386);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('HSQ', 'Hsinchu', 386);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('HSZ', 'Hsinchu', 386);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('HUA', 'Hualien', 386);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('ILA', 'Yilan', 386);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('KEE', 'Keelung', 386);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('KHH', 'Kaohsiung', 386);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('KIN', 'Kinmen', 386);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('LIE', 'Lienchiang', 386);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('MIA', 'Miaoli', 386);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('NAN', 'Nantou', 386);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('NWT', 'New Taipei', 386);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('PEN', 'Penghu', 386);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('PIF', 'Pingtung', 386);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('TAO', 'Taoyuan', 386);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('TNN', 'Tainan', 386);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('TPE', 'Taipei', 386);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('TTT', 'Taitung', 386);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('TXG', 'Taichung', 386);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('YUN', 'Yunlin', 386);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('01', 'Zagrebačka županija', 497);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('02', 'Krapinsko-Zagorska županija', 497);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('03', 'Sisačko-Moslavačka županija', 497);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('04', 'Karlovačka županija', 497);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('05', 'Varaždinska županija', 497);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('06', 'Koprivničko-Križevačka županija', 497);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('07', 'Bjelovarsko-Bilogorska županija', 497);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('08', 'Primorsko-Goranska županija', 497);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('09', 'Ličko-Senjska županija', 497);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('10', 'Virovitičko-Podravska županija', 497);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('11', 'Požeško-Slavonska županija', 497);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('12', 'Brodsko-Posavska županija', 497);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('13', 'Zadarska županija', 497);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('14', 'Osječko-Baranjska županija', 497);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('15', 'Šibensko-Kninska županija', 497);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('16', 'Vukovarsko-Srijemska županija', 497);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('17', 'Splitsko-Dalmatinska županija', 497);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('18', 'Istarska županija', 497);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('19', 'Dubrovačko-Neretvanska županija', 497);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('20', 'Međimurska županija', 497);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('21', 'Grad Zagreb', 497);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('APA', 'Praha 1', 503);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('APB', 'Praha 2', 503);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('APC', 'Praha 3', 503);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('APD', 'Praha 4', 503);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('APE', 'Praha 5', 503);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('APF', 'Praha 6', 503);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('APG', 'Praha 7', 503);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('APH', 'Praha 8', 503);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('API', 'Praha 9', 503);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('APJ', 'Praha 10', 503);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('BBE', 'Beroun', 503);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('BBN', 'Benesov', 503);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('BKD', 'Kladno', 503);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('BKH', 'Kutna Hora', 503);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('BKO', 'Kolin', 503);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('BMB', 'Mlada Boleslav', 503);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('BME', 'Melnik', 503);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('BNY', 'Nymburk', 503);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('BPB', 'Pribram', 503);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('BPV', 'Praha vychod', 503);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('BPZ', 'Praha zapad', 503);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('BRA', 'Rakovnik', 503);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('CBU', 'Ceske Budejovice', 503);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('CCK', 'Cesky Krumlov', 503);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('CJH', 'Jindrichuv Hradec', 503);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('CPE', 'Pelhrimov', 503);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('CPI', 'Pisek', 503);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('CPR', 'Prachatice', 503);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('CST', 'Strakonice', 503);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('CTA', 'Tabor', 503);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('DCH', 'Cheb', 503);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('DDO', 'Domazlice', 503);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('DKL', 'Klatovy', 503);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('DKV', 'Karlovy Vary', 503);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('DPJ', 'Plzen jih', 503);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('DPM', 'Plzen mesto', 503);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('DPS', 'Plzen sever', 503);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('DRO', 'Rokycany', 503);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('DSO', 'Sokolov', 503);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('DTA', 'Tachov', 503);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('ECH', 'Chomutov', 503);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('ECL', 'Ceska Lipa', 503);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('EDE', 'Decin', 503);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('EJA', 'Jablonec n. Nisou', 503);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('ELI', 'Liberec', 503);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('ELO', 'Louny', 503);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('ELT', 'Litomerice', 503);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('EMO', 'Most', 503);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('ETE', 'Teplice', 503);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('EUL', 'Usti nad Labem', 503);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('FCR', 'Chrudim', 503);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('FHB', 'Havlickuv Brod', 503);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('FHK', 'Hradec Kralove', 503);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('FJI', 'Jicin', 503);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('FNA', 'Nachod', 503);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('FPA', 'Pardubice', 503);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('FRK', 'Rychn n. Kneznou', 503);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('FSE', 'Semily', 503);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('FSV', 'Svitavy', 503);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('FTR', 'Trutnov', 503);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('FUO', 'Usti nad Orlici', 503);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('GBL', 'Blansko', 503);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('GBM', 'Brno mesto', 503);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('GBR', 'Breclav', 503);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('GBV', 'Brno venkov', 503);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('GHO', 'Hodonin', 503);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('GJI', 'Jihlava', 503);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('GKR', 'Kromeriz', 503);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('GPR', 'Prostejov', 503);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('GTR', 'Trebic', 503);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('GUH', 'Uherske Hradiste', 503);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('GVY', 'Vyskov', 503);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('GZL', 'Zlin', 503);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('GZN', 'Znojmo', 503);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('GZS', 'Zdar nad Sazavou', 503);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('HBR', 'Bruntal', 503);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('HFM', 'Frydek-Mistek', 503);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('HJE', 'Jesenik', 503);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('HKA', 'Karvina', 503);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('HNJ', 'Novy Jicin', 503);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('HOL', 'Olomouc', 503);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('HOP', 'Opava', 503);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('HOS', 'Ostrava', 503);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('HPR', 'Prerov', 503);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('HSU', 'Sumperk', 503);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('HVS', 'Vsetin', 503);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('BAA', 'Bratislava 1', 504);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('BAB', 'Bratislava 2', 504);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('BAC', 'Bratislava 3', 504);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('BAD', 'Bratislava 4', 504);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('BAE', 'Bratislava 5', 504);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('BAN', 'Banovce n. Bebr.', 504);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('BAR', 'Bardejov', 504);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('BBY', 'Banska Bystrica', 504);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('BRE', 'Brezno', 504);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('BST', 'Banska Stiavnica', 504);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('BYT', 'Bytca', 504);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('CAD', 'Cadca', 504);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('DET', 'Detva', 504);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('DKU', 'Dolny Kubin', 504);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('DST', 'Dunajska Streda', 504);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('GAL', 'Galanta', 504);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('GEL', 'Gelnica', 504);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('HLO', 'Hlohovec', 504);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('HUM', 'Humenne', 504);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('ILA', 'Ilava', 504);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('KEA', 'Kosice 1', 504);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('KEB', 'Kosice 2', 504);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('KEC', 'Kosice 3', 504);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('KED', 'Kosice 4', 504);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('KEO', 'Kosice-okolie', 504);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('KEZ', 'Kezmarok', 504);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('KNM', 'Kysucke N. Mesto', 504);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('KOM', 'Komarno', 504);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('KRU', 'Krupina', 504);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('LEV', 'Levoca', 504);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('LMI', 'Liptovsky Mikulas', 504);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('LUC', 'Lucenec', 504);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('LVC', 'Levice', 504);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('MAL', 'Malacky', 504);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('MAR', 'Martin', 504);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('MED', 'Medzilaborce', 504);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('MIC', 'Michalovce', 504);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('MYJ', 'Myjava', 504);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('NAM', 'Namestovo', 504);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('NIT', 'Nitra', 504);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('NMV', 'Nove Mesto n. Vah', 504);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('NZA', 'Nove Zamky', 504);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('PAR', 'Partizanske', 504);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('PBY', 'Povazska Bystrica', 504);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('PEZ', 'Pezinok', 504);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('PIE', 'Piestany', 504);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('POL', 'Poltar', 504);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('POP', 'Poprad', 504);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('PRE', 'Presov', 504);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('PRI', 'Prievidza', 504);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('PUC', 'Puchov', 504);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('REV', 'Revuca', 504);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('ROZ', 'Roznava', 504);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('RSO', 'Rimavska Sobota', 504);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('RUZ', 'Ruzomberok', 504);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('SAB', 'Sabinov', 504);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('SAL', 'Sala', 504);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('SEA', 'Senica', 504);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('SEN', 'Senec', 504);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('SKA', 'Skalica', 504);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('SLU', 'Stara Lubovna', 504);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('SNI', 'Snina', 504);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('SNV', 'Spisska Nova Ves', 504);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('SOB', 'Sobrance', 504);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('STR', 'Stropkov', 504);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('SVI', 'Svidnik', 504);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('TNC', 'Trencin', 504);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('TOP', 'Topolcany', 504);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('TRE', 'Trebisov', 504);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('TRN', 'Trnava', 504);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('TTE', 'Turcianske Teplice', 504);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('TVR', 'Tvrdosin', 504);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('VKR', 'Velky Krtis', 504);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('VRT', 'Vranov nad Toplou', 504);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('ZAR', 'Zarnovica', 504);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('ZIH', 'Ziar nad Hronom', 504);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('ZIL', 'Zilina', 504);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('ZMO', 'Zlate Moravce', 504);
INSERT OR IGNORE INTO adif_enum_primary_subdivision (code, subdivision_name, dxcc) VALUES ('ZVO', 'Zvolen', 504);
